/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.jmeter.testelement;

public class WorkBench extends AbstractTestElement {

    private static final long serialVersionUID = 240L;

    // JMX property name: do not change
    private static final String SAVE_WORKBENCH = "WorkBench.save";

    private static final boolean SAVE_WORKBENCH_DEFAULT = false;

    public WorkBench() {
    }

    public boolean getSaveWorkBench() {
        return getPropertyAsBoolean(SAVE_WORKBENCH, SAVE_WORKBENCH_DEFAULT);
    }

    public void setSaveWorkBench(boolean saveWorkBench) {
        setProperty(SAVE_WORKBENCH, saveWorkBench, SAVE_WORKBENCH_DEFAULT);
    }
}
